pub struct PythonDownloadRequest { /* private fields */ }Implementations
Sourceimpl PythonDownloadRequest
impl PythonDownloadRequest
pub fn new( version: Option<VersionRequest>, implementation: Option<ImplementationName>, arch: Option<ArchRequest>, os: Option<Os>, libc: Option<Libc>, prereleases: Option<bool>, ) -> Self
pub fn with_version(self, version: VersionRequest) -> Self
pub fn with_arch(self, arch: Arch) -> Self
pub fn with_any_arch(self) -> Self
pub fn with_prereleases(self, prereleases: bool) -> Self
Sourcepub fn from_request(request: &PythonRequest) -> Option<Self>
pub fn from_request(request: &PythonRequest) -> Option<Self>
Construct a new PythonDownloadRequest from a PythonRequest if possible.
Returns None if the request kind is not compatible with a download, e.g., it is
a request for a specific directory or executable name.
Sourcepub fn fill_platform(self) -> Result<Self, Error>
pub fn fill_platform(self) -> Result<Self, Error>
Fill empty entries with default values.
Platform information is pulled from the environment.
pub fn fill(self) -> Result<Self, Error>
pub fn implementation(&self) -> Option<&ImplementationName>
pub fn version(&self) -> Option<&VersionRequest>
pub fn arch(&self) -> Option<&ArchRequest>
pub fn os(&self) -> Option<&Os>
pub fn libc(&self) -> Option<&Libc>
pub fn take_version(&mut self) -> Option<VersionRequest>
Sourcepub fn simplified_display(self) -> Option<String>
pub fn simplified_display(self) -> Option<String>
Return a compact string representation suitable for user-facing display.
The resulting string only includes explicitly-set pieces of the request and returns
None when no segments are explicitly set.
Sourcepub fn satisfied_by_key(&self, key: &PythonInstallationKey) -> bool
pub fn satisfied_by_key(&self, key: &PythonInstallationKey) -> bool
Whether this request is satisfied by an installation key.
Sourcepub fn allows_prereleases(&self) -> bool
pub fn allows_prereleases(&self) -> bool
Whether this download request opts-in to pre-release Python versions.
Sourcepub fn platform(&self) -> PlatformRequest
pub fn platform(&self) -> PlatformRequest
Extract the platform components of this request.