pub enum VersionRequest {
Default,
Any,
Major(u8, PythonVariant),
MajorMinor(u8, u8, PythonVariant),
MajorMinorPatch(u8, u8, u8, PythonVariant),
MajorMinorPrerelease(u8, u8, Prerelease, PythonVariant),
MajorMinorPatchPrerelease(u8, u8, u8, Prerelease, PythonVariant),
Range(VersionSpecifiers, PythonVariant),
}Expand description
A Python discovery version request.
Variants
Default
Allow an appropriate default Python version.
Any
Allow any Python version.
Major(u8, PythonVariant)
MajorMinor(u8, u8, PythonVariant)
MajorMinorPatch(u8, u8, u8, PythonVariant)
MajorMinorPrerelease(u8, u8, Prerelease, PythonVariant)
MajorMinorPatchPrerelease(u8, u8, u8, Prerelease, PythonVariant)
Range(VersionSpecifiers, PythonVariant)
Implementations
Sourceimpl VersionRequest
impl VersionRequest
Sourcepub fn from_specifiers(
specifiers: VersionSpecifiers,
variant: PythonVariant,
) -> Self
pub fn from_specifiers( specifiers: VersionSpecifiers, variant: PythonVariant, ) -> Self
Create a VersionRequest from VersionSpecifiers.
If the specifiers consist of a single == constraint, the version is parsed as a
concrete version request (e.g., MajorMinorPatch) rather than a range.
Sourcepub fn only_minor(self) -> Self
pub fn only_minor(self) -> Self
Drop any patch or prerelease information from the version request.
Sourcepub fn without_python_variant(self) -> Self
pub fn without_python_variant(self) -> Self
Return a new VersionRequest with the PythonVariant if it has one.
This is useful for converting the string representation to pep440.
Sourcepub fn as_pep440_version(&self) -> Option<Version>
pub fn as_pep440_version(&self) -> Option<Version>
Convert this request into a concrete PEP 440 Version when possible.
Returns None for non-concrete requests
Sourcepub fn as_version_specifiers(&self) -> Option<VersionSpecifiers>
pub fn as_version_specifiers(&self) -> Option<VersionSpecifiers>
Convert this request into VersionSpecifiers representing the range of compatible
versions.
Returns None for requests without version constraints (e.g., VersionRequest::Default
and VersionRequest::Any).