replace_link_to_executable

Function replace_link_to_executable 

pub fn replace_link_to_executable(
    link: &Path,
    executable: &Path,
) -> Result<(), Error>
Create or replace a link to a managed Python executable.

If a file already exists at the link path, it will be atomically replaced.

See create_link_to_executable for a variant that errors if the link already exists.