PythonInstallation

Struct PythonInstallation 

pub struct PythonInstallation { /* private fields */ }
A Python interpreter and accompanying tools.

Implementations

Source

impl PythonInstallation

pub fn new(source: PythonSource, interpreter: Interpreter) -> Self

Create a new PythonInstallation from a source and interpreter.

pub fn find( request: &PythonRequest, environments: EnvironmentPreference, preference: PythonPreference, download_list: &ManagedPythonDownloadList, cache: &Cache, preview: Preview, ) -> Result<Self, Error>

Find an installed PythonInstallation.

This is the standard interface for discovering a Python installation for creating an environment. If interested in finding an existing environment, see [PythonEnvironment::find] instead.

Note we still require an EnvironmentPreference as this can either bypass virtual environments or prefer them. In most cases, this should be EnvironmentPreference::OnlySystem but if you want to allow an interpreter from a virtual environment if it satisfies the request, then use EnvironmentPreference::Any.

See [find_installation] for implementation details.

pub fn find_existing( request: &PythonRequest, environments: EnvironmentPreference, preference: PythonPreference, cache: &Cache, preview: Preview, ) -> Result<Self, Error>

Find an existing PythonInstallation.

pub async fn find_best( request: &PythonRequest, environments: EnvironmentPreference, preference: PythonPreference, python_downloads: PythonDownloads, client_builder: &BaseClientBuilder<'_>, cache: &Cache, reporter: Option<&dyn Reporter>, python_install_mirror: Option<&str>, pypy_install_mirror: Option<&str>, python_downloads_json_url: Option<&str>, preview: Preview, ) -> Result<Self, Error>

Find or download a PythonInstallation that satisfies a requested version, if the request cannot be satisfied, fallback to the best available Python installation.

pub async fn find_or_download( request: Option<&PythonRequest>, environments: EnvironmentPreference, preference: PythonPreference, python_downloads: PythonDownloads, client_builder: &BaseClientBuilder<'_>, cache: &Cache, reporter: Option<&dyn Reporter>, python_install_mirror: Option<&str>, pypy_install_mirror: Option<&str>, python_downloads_json_url: Option<&str>, preview: Preview, ) -> Result<Self, Error>

Find or fetch a PythonInstallation.

Unlike PythonInstallation::find, if the required Python is not installed it will be installed automatically.

pub async fn fetch( download: &ManagedPythonDownload, client: &BaseClient, retry_policy: &ExponentialBackoff, cache: &Cache, reporter: Option<&dyn Reporter>, python_install_mirror: Option<&str>, pypy_install_mirror: Option<&str>, ) -> Result<Self, Error>

Download and install the requested installation.

pub fn from_interpreter(interpreter: Interpreter) -> Self

Create a PythonInstallation from an existing Interpreter.

pub fn source(&self) -> &PythonSource

Return the PythonSource of the Python installation, indicating where it was found.

pub fn key(&self) -> PythonInstallationKey

pub fn python_version(&self) -> &Version

Return the Python Version of the Python installation as reported by its interpreter.

pub fn implementation(&self) -> LenientImplementationName

Return the LenientImplementationName of the Python installation as reported by its interpreter.

pub fn is_managed(&self) -> bool

Returns true if this is a managed (uv-installed) Python installation.

Uses the source as a fast path, then falls back to checking the interpreter’s base prefix.

pub fn arch(&self) -> Arch

Return the Arch of the Python installation as reported by its interpreter.

pub fn libc(&self) -> Libc

Return the Libc of the Python installation as reported by its interpreter.

pub fn os(&self) -> Os

Return the Os of the Python installation as reported by its interpreter.

pub fn interpreter(&self) -> &Interpreter

Return the Interpreter for the Python installation.

pub fn into_interpreter(self) -> Interpreter

Consume the PythonInstallation and return the Interpreter.

pub async fn download_and_warn_if_outdated_prerelease( &self, request: &PythonRequest, client_builder: &BaseClientBuilder<'_>, python_downloads_json_url: Option<&str>, ) -> Result<(), Error>

Emit a warning when the interpreter is a managed prerelease and a matching stable build can be installed via uv python upgrade.

Avoids loading the Python download list unless the discovered interpreter could require the warning.